#ifndef NT2_INCLUDE_CONSTANTS_PROPERTIES_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PROPERTIES_HPP_INCLUDED

#include <nt2/constant/include/constants/properties.hpp>

#endif
